=======
Credits
=======

Development Lead
----------------

* Kalyan Veeramachaneni <kalyan@mit.edu>
* Kevin Zhang <kevz@mit.edu>

Contributors
------------

* Plamen Valentinov <plamen@pythiac.com>
* Carles Sala <csala@csail.mit.edu>
